@@ -19,7 +19,9 @@
 package main
 
 import (
+	"context"
 	"encoding/json"
+	"flag"
 	"fmt"
 	"io/ioutil"
 	"net"
@@ -32,7 +34,7 @@ import (
 	"github.com/containernetworking/cni/pkg/invoke"
 	"github.com/containernetworking/cni/pkg/skel"
 	cnitypes "github.com/containernetworking/cni/pkg/types"
-	"github.com/containernetworking/cni/pkg/version"
+	cniversion "github.com/containernetworking/cni/pkg/version"
 	"github.com/containernetworking/plugins/pkg/ns"
 	k8s "github.com/intel/multus-cni/k8sclient"
 	"github.com/intel/multus-cni/logging"
@@ -41,6 +43,10 @@ import (
 	"k8s.io/apimachinery/pkg/util/wait"
 )
 
+var version = "master@git"
+var commit = "unknown commit"
+var date = "unknown date"
+
 var defaultReadinessBackoff = wait.Backoff{
 	Steps:    4,
 	Duration: 250 * time.Millisecond,
@@ -48,6 +54,11 @@ var defaultReadinessBackoff = wait.Backoff{
 	Jitter:   0.1,
 }
 
+func printVersionString() string {
+	return fmt.Sprintf("multus-cni version:%s, commit:%s, date:%s",
+		version, commit, date)
+}
+
 func saveScratchNetConf(containerID, dataDir string, netconf []byte) error {
 	logging.Debugf("saveScratchNetConf: %s, %s, %s", containerID, dataDir, string(netconf))
 	if err := os.MkdirAll(dataDir, 0700); err != nil {
@@ -145,7 +156,7 @@ func conflistAdd(rt *libcni.RuntimeConf, rawnetconflist []byte, binDir string, e
 		return nil, logging.Errorf("error in converting the raw bytes to conflist: %v", err)
 	}
 
-	result, err := cniNet.AddNetworkList(confList, rt)
+	result, err := cniNet.AddNetworkList(context.Background(), confList, rt)
 	if err != nil {
 		return nil, logging.Errorf("error in getting result from AddNetworkList: %v", err)
 	}
@@ -165,7 +176,7 @@ func conflistDel(rt *libcni.RuntimeConf, rawnetconflist []byte, binDir string, e
 		return logging.Errorf("error in converting the raw bytes to conflist: %v", err)
 	}
 
-	err = cniNet.DelNetworkList(confList, rt)
+	err = cniNet.DelNetworkList(context.Background(), confList, rt)
 	if err != nil {
 		return logging.Errorf("error in getting result from DelNetworkList: %v", err)
 	}
@@ -227,7 +238,10 @@ func delegateAdd(exec invoke.Exec, ifName string, delegate *types.DelegateNetCon
 			return nil, logging.Errorf("Multus: error in invoke Conflist add - %q: %v", delegate.ConfList.Name, err)
 		}
 	} else {
-		result, err = invoke.DelegateAdd(delegate.Conf.Type, delegate.Bytes, exec)
+		origpath := os.Getenv("CNI_PATH")
+		os.Setenv("CNI_PATH", origpath+":"+binDir)
+		result, err = invoke.DelegateAdd(context.Background(), delegate.Conf.Type, delegate.Bytes, exec)
+		os.Setenv("CNI_PATH", origpath)
 		if err != nil {
 			return nil, logging.Errorf("Multus: error in invoke Delegate add - %q: %v", delegate.Conf.Type, err)
 		}
@@ -271,9 +285,13 @@ func delegateDel(exec invoke.Exec, ifName string, delegateConf *types.DelegateNe
 			return logging.Errorf("Multus: error in invoke Conflist Del - %q: %v", delegateConf.ConfList.Name, err)
 		}
 	} else {
-		if err = invoke.DelegateDel(delegateConf.Conf.Type, delegateConf.Bytes, exec); err != nil {
+		origpath := os.Getenv("CNI_PATH")
+		os.Setenv("CNI_PATH", origpath+":"+binDir)
+		if err = invoke.DelegateDel(context.Background(), delegateConf.Conf.Type, delegateConf.Bytes, exec); err != nil {
+			os.Setenv("CNI_PATH", origpath)
 			return logging.Errorf("Multus: error in invoke Delegate del - %q: %v", delegateConf.Conf.Type, err)
 		}
+		os.Setenv("CNI_PATH", origpath)
 	}
 
 	return err
@@ -406,16 +424,12 @@ func cmdGet(args *skel.CmdArgs, exec invoke.Exec, kubeClient k8s.KubeClient) (cn
 }
 
 func cmdDel(args *skel.CmdArgs, exec invoke.Exec, kubeClient k8s.KubeClient) error {
-	in, err := types.LoadNetConf(args.StdinData)
 	logging.Debugf("cmdDel: %v, %v, %v", args, exec, kubeClient)
+	in, err := types.LoadNetConf(args.StdinData)
 	if err != nil {
 		return err
 	}
 
-	if args.Netns == "" {
-		return nil
-	}
-
 	netnsfound := true
 	netns, err := ns.GetNS(args.Netns)
 	if err != nil {
@@ -425,7 +439,7 @@ func cmdDel(args *skel.CmdArgs, exec invoke.Exec, kubeClient k8s.KubeClient) err
 		_, ok := err.(ns.NSPathNotExistErr)
 		if ok {
 			netnsfound = false
-			logging.Debugf("cmdDel: WARNING netns may not exist, netns: %s, err: %s", netns, err)
+			logging.Debugf("cmdDel: WARNING netns may not exist, netns: %s, err: %s", args.Netns, err)
 		} else {
 			return fmt.Errorf("failed to open netns %q: %v", netns, err)
 		}
@@ -504,6 +518,20 @@ func cmdDel(args *skel.CmdArgs, exec invoke.Exec, kubeClient k8s.KubeClient) err
 }
 
 func main() {
+
+	// Init command line flags to clear vendored packages' one, especially in init()
+	flag.CommandLine = flag.NewFlagSet(os.Args[0], flag.ExitOnError)
+
+	// add version flag
+	versionOpt := false
+	flag.BoolVar(&versionOpt, "version", false, "Show application version")
+	flag.BoolVar(&versionOpt, "v", false, "Show application version")
+	flag.Parse()
+	if versionOpt == true {
+		fmt.Printf("%s\n", printVersionString())
+		return
+	}
+
 	skel.PluginMain(
 		func(args *skel.CmdArgs) error {
 			result, err := cmdAdd(args, nil, nil)
@@ -520,5 +548,5 @@ func main() {
 			return result.Print()
 		},
 		func(args *skel.CmdArgs) error { return cmdDel(args, nil, nil) },
-		version.All, "meta-plugin that delegates to other CNI plugins")
+		cniversion.All, "meta-plugin that delegates to other CNI plugins")
 }
