@@ -16,6 +16,7 @@
 package main
 
 import (
+	"context"
 	"encoding/json"
 	"fmt"
 	"io/ioutil"
@@ -28,7 +29,7 @@ import (
 	"github.com/containernetworking/cni/pkg/skel"
 	cnitypes "github.com/containernetworking/cni/pkg/types"
 	"github.com/containernetworking/cni/pkg/types/020"
-	"github.com/containernetworking/cni/pkg/version"
+	cniversion "github.com/containernetworking/cni/pkg/version"
 	"github.com/containernetworking/plugins/pkg/ns"
 	"github.com/containernetworking/plugins/pkg/testutils"
 
@@ -52,7 +53,7 @@ type fakePlugin struct {
 }
 
 type fakeExec struct {
-	version.PluginDecoder
+	cniversion.PluginDecoder
 
 	addIndex int
 	delIndex int
@@ -97,7 +98,7 @@ func gatherCNIEnv() []string {
 	return filtered
 }
 
-func (f *fakeExec) ExecPlugin(pluginPath string, stdinData []byte, environ []string) ([]byte, error) {
+func (f *fakeExec) ExecPlugin(ctx context.Context, pluginPath string, stdinData []byte, environ []string) ([]byte, error) {
 	cmd := os.Getenv("CNI_COMMAND")
 	var index int
 	switch cmd {
